<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="6" name="kdesvn" >
 <MenuBar>
 <Menu noMerge="1" name="file"><text>&amp;File</text>
    <Action name="file_open"/>
    <Action name="file_open_recent"/>
    <Action name="file_new"/>
    <Separator/>
    <Menu name="subversion_admin" noMerge="1">
        <text>Subversion Admin</text>
        <Action name="subversion_create_repo"/>
        <Action name="subversion_dump_repo"/>
        <Action name="subversion_hotcopy_repo"/>
        <Action name="subversion_load_repo"/>
        <Merge/>
    </Menu>
    <Separator/>
    <Merge/>
    <Action name="file_close"/>
    <Separator/>
    <Action name="file_quit"/>
 </Menu>
  <Action name="bookmarks" />
  <Menu noMerge="1" name="subversion_main" >
      <text>Subversion</text>
      <Merge/>
      <Action name="kdesvn_ssh_add"/>
  </Menu>
  <Menu noMerge="1" name="settings">
    <text>&amp;Settings</text>
    <Action name="options_show_toolbar"/>
    <Action name="options_show_statusbar"/>
    <Separator />
    <Action name="toggle_load_last_url" />
    <Action name="show_merge" />
    <Separator />
    <Action name="options_configure_keybinding"/>
    <Action name="options_configure_toolbars"/>
    <Merge name="configure_merge"/>
    <Separator/>
    <Merge/>
  </Menu>
  <Menu noMerge="0" name="help">
      <text>&amp;Help</text>
      <Merge/>
      <Action name="help_about_kdesvnpart"/>
  </Menu>
 </MenuBar>
<ToolBar name="subversionToolBar" noMerge="1">
<text>Subversion toolbar</text>
<Merge/>
</ToolBar>
 <ToolBar noMerge="1" name="mainToolBar" >
  <text>Main Toolbar</text>
  <Action name="file_open" />
  <Merge/>
  <Action name="file_close"/>
  <Action name="help" />
 </ToolBar>
</kpartgui>
