<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kdesvn_part" version="17">
<MenuBar>
  <Menu noMerge="1" name="settings">
    <Action name="kdesvnpart_pref" />
    <Menu name="quicksettings">
     <text>Quick settings</text>
     <Action name="toggle_log_follows" />
     <Action name="toggle_ignored_files" />
     <Action name="toggle_unknown_files" />
     <Action name="toggle_hide_unchanged_files" />
     <Action name="toggle_network"/>
   </Menu>
  </Menu>
  <Menu name="subversion_main" >
   <text>Subversion</text>
   <Menu name="subversion_general" >
    <text>General</text>
    <Action name="make_svn_log_full" />
    <Action name="make_svn_log" />
    <Action name="make_svn_tree" />
    <Action name="make_svn_partialtree" />
    <Action name="make_svn_info" />
    <Action name="make_revisions_diff" />
    <Action name="make_last_change" />
    <Action name="make_svn_itemsdiff" />
    <Action name="make_svn_merge" />
    <Separator/>
    <Action name="make_svn_blame" />
    <Action name="make_svn_range_blame" />
    <Action name="make_svn_cat" />
    <Action name="make_revisions_cat" />
    <Separator/>
    <Action name="make_svn_rename" />
    <Action name="make_svn_copy" />
    <Action name="make_svn_remove" />
    <Action name="make_svn_mkdir" />
    <Action name="make_import_dirs_into_current" />
    <Separator/>
    <Action name="make_svn_checkout" />
    <Action name="make_svn_export" />
    <Action name="make_svn_export_current" />
    <Separator/>
    <Action name="make_svn_lock"/>
    <Action name="make_svn_unlock"/>
   </Menu>
   <Menu name="subversion_working_copy" >
    <text>Working copy</text>
    <Action name="make_svn_headupdate" />
    <Action name="make_svn_revupdate" />
    <Action name="make_svn_commit" />
    <Action name="make_svn_basediff" />
    <Action name="make_svn_headdiff" />
    <Action name="make_svn_property" />
    <Separator/>
    <Action name="make_svn_add" />
    <Action name="make_svn_addrec" />
    <Action name="make_check_unversioned" />
    <Action name="make_svn_revert" />
    <Action name="make_try_resolve"/>
    <Action name="make_resolved" />
    <Action name="make_svn_merge_revisions" />
    <Action name="make_svn_ignore" />
    <Separator/>
    <Action name="make_cleanup" />
    <Action name="make_svn_switch" />
    <Action name="make_svn_relocate" />
    <Separator/>
    <Action name="make_switch_to_repo" />
    <Action name="make_check_updates" />
   </Menu>
   <Menu name="subversion_repo" >
    <text>Repository</text>
    <Action name="make_svn_checkout_current" />
    <Separator/>
    <Action name="switch_browse_revision" />
   </Menu>
   <Separator/>
    <Menu name="generic_view">
        <text>View</text>
        <Action name="make_view_refresh" />
        <Action name="view_unfold_tree" />
        <Action name="view_fold_tree" />
    </Menu>
    <Separator/>
    <Menu name="log_cache">
        <text>Logcache</text>
        <Action name="update_log_cache"/>
    </Menu>
    <Separator/>
  </Menu>
  <Menu name="help"><text>&amp;Help</text>
   <Separator/>
   <Action name="help_about_kdesvnpart" />
   <Action name="help_kdesvn" />
   <Action name="report_bug" />
  </Menu>
</MenuBar>
 <Menu name="local_context_single_conflicted">
     <text>Actions</text>
     <Action name="make_resolved" />
     <Action name="make_try_resolve"/>
 </Menu>
 <Menu name="local_context_single_versioned" >
  <text>Actions</text>
  <Action name="make_svn_headupdate"/>
  <Action name="make_svn_commit" />
  <Action name="make_svn_log_full" />
  <Action name="make_svn_basediff" />
  <Action name="make_svn_headdiff" />
  <Action name="make_last_change" />
  <Action name="make_svn_cat" />
  <Separator/>
  <Action name="make_svn_lock" />
  <Action name="make_svn_unlock" />
  <Separator/>
  <Action name="make_svn_rename" />
  <Action name="make_svn_remove" />
  <Separator/>
 </Menu>
 <Menu name="local_context_single_versioned_dir">
     <Action name="make_svn_headupdate"/>
     <Action name="make_svn_commit" />
     <Action name="make_svn_log_full" />
     <Action name="make_svn_basediff" />
     <Action name="make_svn_headdiff" />
     <Action name="make_last_change" />
     <Separator/>
     <Action name="make_cleanup" />
     <Separator/>
     <Action name="make_svn_remove" />
     <Action name="make_svn_rename" />
     <Action name="make_svn_mkdir" />
     <Action name="make_view_refresh" />
 </Menu>
 <Menu name="local_context_single_unversioned" >
     <text>Actions</text>
     <Action name="make_svn_add"/>
     <Action name="make_svn_ignore"/>
     <Action name="make_svn_remove" />
     <Separator/>
 </Menu>
 <Menu name="local_context_multi" >
     <text>Actions</text>
     <Action name="make_svn_headupdate"/>
     <Action name="make_svn_commit" />
     <Action name="make_svn_basediff" />
     <Action name="make_svn_headdiff" />
     <Action name="make_svn_itemsdiff" />
     <Separator/>
     <Action name="make_view_refresh" />
 </Menu>
 <Menu name="remote_context_single" >
  <Action name="make_svn_log_full" />
  <Action name="make_svn_blame" />
  <Action name="make_svn_cat" />
  <Action name="get_svn_property" />
  <Action name="make_last_change" />
  <Separator/>
  <Action name="make_svn_lock" />
  <Action name="make_svn_unlock" />
  <Separator/>
  <Action name="make_svn_rename" />
  <Action name="make_svn_remove" />
  <Separator/>
 </Menu>
 <Menu name="remote_context_single_dir" >
     <Action name="make_svn_log_full" />
     <Action name="make_svn_checkout_current" />
     <Action name="make_svn_export_current" />
     <Action name="get_svn_property" />
     <Action name="make_last_change" />
     <Separator/>
     <Action name="make_svn_mkdir" />
     <Action name="make_svn_rename" />
     <Action name="make_svn_remove" />
     <Separator/>
     <Action name="make_view_refresh" />
 </Menu>
 <Menu name="remote_context_multi" >
  <Action name="make_svn_log_full" />
  <Action name="make_svn_checkout_current" />
  <Action name="make_svn_export_current" />
  <Action name="make_svn_blame" />
  <Action name="make_svn_cat" />
  <Separator/>
  <Action name="make_svn_itemsdiff" />
  <Separator/>
  <Action name="make_svn_remove" />
  <Action name="make_view_refresh" />
 </Menu>
 <Menu name="local_general">
  <Action name="make_svn_headupdate" />
  <Action name="make_svn_commit" />
  <Separator/>
  <Action name="make_svn_mkdir" />
  <Action name="make_view_refresh" />
  <Action name="make_cleanup" />
 </Menu>
 <Menu name="remote_general">
  <Action name="make_svn_mkdir" />
  <Action name="make_svn_itemsdiff" />
  <Separator/>
  <Action name="make_svn_checkout_current" />
  <Action name="make_svn_export_current" />
  <Separator/>
  <Action name="make_view_refresh" />
 </Menu>
 <Menu name="empty_general" >
  <Action name="file_open" />
  <Action name="open_remote_repository" />
  <Separator/>
  <Action name="bookmarks" />
  <Separator/>
  <Action name="make_svn_checkout" />
  <Action name="make_svn_export" />
 </Menu>
 <ToolBar name="subversionToolBar">
  <text>Subversion toolbar</text>
  <Action name="make_svn_headupdate" />
  <Action name="make_svn_commit" />
  <Action name="make_check_updates" />
  <Separator name="separator_3" />
  <Action name="make_svn_log_full" />
  <Action name="make_svn_info" />
  <Action name="make_svn_blame" />
  <Separator name="separator_2" />
  <Action name="make_svn_add" />
  <Action name="make_check_unversioned" />
  <Action name="make_svn_remove" />
  <Action name="make_svn_merge_revisions" />
  <Separator name="separator_1" />
  <Action name="make_svn_checkout" />
  <Action name="make_svn_export" />
  <Separator name="separator_0" />
  <Action name="make_view_refresh" />
 </ToolBar>
 <ToolBar name="mainToolBar" >
  <text>Main Toolbar</text>
  <Action name="file_open" />
  <Action name="file_close" />
 </ToolBar>
</kpartgui>
