/***************************************************************************
 *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
 *   ral@alwins-world.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef _SVNQT_DEFINES_H
#define _SVNQT_DEFINES_H

/* defines if we setup against a compiler with working "-fvisibility=hidden" */
#define SVNQT_EXPORT __attribute__ ((visibility("default")))
#define SVNQT_NOEXPORT __attribute__ ((visibility("hidden")))

/* cmake trick: so we make sure that the define in installs
   is always set as in library used at build time
 */
#define TOUTF8 utf8
#define FROMUTF8 fromUtf8
#define QLIST QValueList
#define TOASCII latin1
#define HOMEDIR homeDirPath
#define QLONG Q_LLONG

#define SVNQT_SIZE_UNKNOWN QLONG(-1)

/* the difference between qt3 and qt4 is too much... :( */
class QSqlDatabase;
typedef QSqlDatabase* QDataBase;
#endif
